@@ -14,18 +14,26 @@ class Config(object):
     ADMIN_EMAIL = "info@cases.lu"
     ADMIN_URL = "https://www.cases.lu"
 
-    REMOTE_STATS_SERVER = "http://127.0.0.1:5000"
+    REMOTE_STATS_SERVER = "https://dashboard.monarc.lu"
+    REMOTE_STATS_TOKEN = ""
+
+    SECRET_KEY = "LCx3BchmHRxFzkEv4BqQJyeXRLXenf"
+
+    LOG_PATH = "./var/stats.log"
+
+    # Connection with MOSP
+    MOSP_URL = "https://objects.monarc.lu"
 
 
 class ProductionConfig(Config):
     DB_CONFIG_DICT = {
-        "user": "pgsqluser",
-        "password": "pgsqlpwd",
+        "user": "postgres",
+        "password": "password",
         "host": "localhost",
         "port": 5432,
     }
     DATABASE_NAME = "statsservice"
-    SQLALCHEMY_DATABASE_URI = "postgres://{user}:{password}@{host}:{port}/{name}".format(
+    SQLALCHEMY_DATABASE_URI = "postgresql://{user}:{password}@{host}:{port}/{name}".format(
         name=DATABASE_NAME, **DB_CONFIG_DICT
     )
     SQLALCHEMY_TRACK_MODIFICATIONS = False
