@@ -9,7 +9,11 @@ api_blueprint = Blueprint("api", __name__, url_prefix="/api/v1")
 
 def setup_api(application):
     authorizations = {
-        "apikey": {"type": "apiKey", "in": "header", "name": "X-API-KEY",}
+        "apikey": {
+            "type": "apiKey",
+            "in": "header",
+            "name": "X-API-KEY",
+        }
     }
 
     api = Api(
@@ -36,10 +40,11 @@ def setup_api(application):
             ),
         )
 
-    from statsservice.api.v1 import stats, organization
+    from statsservice.api.v1 import stats, client, processed
 
-    api.add_namespace(organization.organization_ns, path="/api/v1/organization")
-    api.add_namespace(stats.stats_ns, path="/api/v1/stats")
+    api.add_namespace(client.client_ns, path="/client")
+    api.add_namespace(stats.stats_ns, path="/stats")
+    api.add_namespace(processed.processed_ns, path="/stats/processed")
 
     return api
 
