@@ -6,27 +6,30 @@ from statsservice.bootstrap import application, db
 
 @application.cli.command("db_empty")
 def db_empty():
-    """Drop all the database.
-    """
+    """Empty the database."""
     if click.confirm("Do you want to drop all the database?"):
         with application.app_context():
             models.db_empty(db)
-            print("Database dropped.")
+            print("Database empty.")
 
 
 @application.cli.command("db_create")
 def db_create():
-    "Will create the database."
-    with application.app_context():
+    "Create the database from configuration parameters."
+    try:
         models.db_create(
             db,
             application.config["DB_CONFIG_DICT"],
             application.config["DATABASE_NAME"],
         )
+    except Exception as e:
+        print(e)
 
 
 @application.cli.command("db_init")
 def db_init():
-    "Will create the database from conf parameters."
-    with application.app_context():
+    "Initialize the database."
+    try:
         models.db_init(db)
+    except Exception as e:
+        print(e)
