@@ -6,14 +6,15 @@
 #
 
 import jsonschema
+from typing import Any
 
 
-def validate_data(data={}, type=""):
+def validate_data(data={}, type: str = ""):
     """Check the validity of the submitted stats data.
     Note: an empty JSON object is validated by any schema but we do not accept
     empty stats.
     """
-    schema = {}
+    schema = {}  # type: dict[Any, Any]
     try:
         jsonschema.validate(data, schema)
     except Exception as e:
